@@ -1036,54 +1036,4 @@ add.dens = function(df3, res, nlevels = 20, z.scale = 1, col = c(1:nnode), ...)
 }
 
 
-#########################
-# function that creates a random tree, polygons with 
-# centroids following BM, and plots in 3D
-
-random_rase3d = function(mean_x = 0, mean_y = 0, 
-	sigma2x = 1, sigma2y = 1, x_ext = c(0.1, 0.5), y_ext = c(0.1, 0.5), 
-	niter = 1000, logevery = 10, plot.3d = TRUE, zscale = 5, pbtree.list = list(n = 10), phylo.3d.list = list(df3, z.scale = zscale, pts = TRUE), add.polygons.list = list(df3, axes = 2), ...) {
-			
-	tree = do.call(pbtree, pbtree.list)
-	nnode = tree$Nnode
-	ntaxa = length(tree$tip.label)
-	x_locs = as.numeric(rmvnorm(1, rep(mean_x,ntaxa), sigma=sigma2x*vcv(tree)))
-	y_locs = as.numeric(rmvnorm(1, rep(mean_y,ntaxa), sigma=sigma2y*vcv(tree)))
-
-	e = 0.5
-	polygons = list()
-	centers = cbind(x_locs, y_locs)
-
-	for(i in 1:ntaxa) {
-	 	r = centers[i,]
-   		polygons[[i]] = matrix(c(r[1]-e,r[1]+e,r[1]+e,r[1]-e,r[1]-e, r[2]-e,r[2]-e,r[2]+e,r[2]+e,r[2]-e), ncol=2)
-	}
-
-	# random convex hulls:
-	npts = 20
-	for(i in 1:ntaxa) {
-	  	xpts = rnorm(npts, x_locs[i], sd=runif(1, x_ext))
-	  	ypts = rnorm(npts, y_locs[i], sd=runif(1, y_ext))
-	  	pts = matrix(c(xpts, ypts),nrow=npts)
-	  	pts = pts[chull(pts), ]
-	  	polygons[[i]] = owin(poly = pts[dim(pts)[1]:1,])
-	}
-	
-	polygons = name.poly(polygons, tree, poly.names = tree$tip.label)
-	
-	res = rase(tree, polygons, niter = niter, logevery = logevery)
-
-	if (plot.3d == TRUE) {
- 		df3 = data.for.3d(res, tree, polygons)
-  		do.call(phylo.3d, phylo.3d.list)
-  		do.call(add.polygons, add.polygons.list)
-  		add.dens(df3, res, nlevels = 10, z.scale = zscale, col = c(1:nnode), ...)
-	}
-	
-	return(res)
-}
-
-
-
-
 
